aboutsummaryrefslogtreecommitdiffstats
path: root/tests/lib/MemoryInfoTest.php
diff options
context:
space:
mode:
Diffstat (limited to 'tests/lib/MemoryInfoTest.php')
-rw-r--r--tests/lib/MemoryInfoTest.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/tests/lib/MemoryInfoTest.php b/tests/lib/MemoryInfoTest.php
index f6557eed45c..1a983f19ece 100644
--- a/tests/lib/MemoryInfoTest.php
+++ b/tests/lib/MemoryInfoTest.php
@@ -71,10 +71,10 @@ class MemoryInfoTest extends TestCase {
* Tests that getMemoryLimit works as expected.
*
* @param string $iniValue The "memory_limit" ini data.
* @param int $expected The expected detected memory limit.
* @dataProvider getMemoryLimitTestData
*/
- public function testMemoryLimit($iniValue, int $expected) {
+ public function testMemoryLimit(string $iniValue, int|float $expected) {
ini_set('memory_limit', $iniValue);
$memoryInfo = new MemoryInfo();
self::assertEquals($expected, $memoryInfo->getMemoryLimit());
@@ -71,10 +71,10 @@ class MemoryInfoTest extends TestCase {
*
* @param string $iniValue The "memory_limit" ini data.
- * @param int $expected The expected detected memory limit.
+ * @param int|float $expected The expected detected memory limit.
* @dataProvider getMemoryLimitTestData
*/